| Title: | Dataset of Measurements of Fish Species at Kirkkojarvi Lake, Finland |
|---|---|
| Description: | Dataset of 302 measurements of 11 fish species to accompany the manuscript "Length-weight relationships of six freshwater fish species from lake Kirkkojarvi, Finland". |
| Authors: | Jose Gama [aut, cre] |
| Maintainer: | Jose Gama <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.0.0 |
| Built: | 2026-05-07 07:44:18 UTC |
| Source: | https://github.com/cran/fishkirkko2015 |
302 lenght measurements of 11 fish species at Kirkkojarvi lake
fishkirkkojarvi2015fishkirkkojarvi2015
dataframe with 302 rows and 6 columns:
Fish name in Finnish
Fish unique identifier for this dataset
Standard Length in mm
Fork Length in mm
Total Length in mm
Weight in g
Jose Gama
## Not run: # get an histogram of the fish species in the dataset data(fishkirkkojarvi2015) hist(fishkirkkojarvi2015[["fishID"]], xaxt="n", main='Histogram of fish species from the Kirkkojarvi lake',xlab='Fish species') axis(1,at=1:10,labels=fishnames[1:10,'English']) ## End(Not run)## Not run: # get an histogram of the fish species in the dataset data(fishkirkkojarvi2015) hist(fishkirkkojarvi2015[["fishID"]], xaxt="n", main='Histogram of fish species from the Kirkkojarvi lake',xlab='Fish species') axis(1,at=1:10,labels=fishnames[1:10,'English']) ## End(Not run)
Names of fish species from Kirkkojarvi lake in Finnish, Swedish, English and Latin (binomial name)
fishnamesfishnames
dataframe with 11 rows and 5 columns:
fish unique identifier for this dataset
Fish name in Finnish
Fish name in English
Fish binomial name in Latin
Fish name in Swedish
Jose Gama
# What is "Kuha" in English and its binomial name? data(fishnames) fishnames[which(fishnames[["Finnish"]]=='Kuha'),c('English','binomial.name')]# What is "Kuha" in English and its binomial name? data(fishnames) fishnames[which(fishnames[["Finnish"]]=='Kuha'),c('English','binomial.name')]